@@ -9,20 +9,16 @@ and Auspice across computing environments such as Docker, Conda, and AWS Batch.
 
 import sys
 import argparse
-from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter, RawDescriptionHelpFormatter
+from argparse import ArgumentParser
 from types    import SimpleNamespace
 
-from .argparse    import register_commands, register_default_command
-from .command     import build, view, deploy, remote, shell, update, check_setup, version
+from .argparse    import HelpFormatter, register_commands, register_default_command
+from .command     import build, view, deploy, remote, shell, update, check_setup, login, logout, whoami, version
 from .errors      import NextstrainCliError
 from .util        import warn
 from .__version__ import __version__
 
 
-class HelpFormatter(ArgumentDefaultsHelpFormatter, RawDescriptionHelpFormatter):
-    pass
-
-
 def run(args):
     """
     Command-line entrypoint to the nextstrain-cli package, called by the
@@ -59,6 +55,9 @@ def make_parser():
         shell,
         update,
         check_setup,
+        login,
+        logout,
+        whoami,
         version,
     ]
 
