@@ -4,16 +4,10 @@ Delete pathogen JSON data files or Markdown narratives from a remote source.
 See `nextstrain remote --help` for more information on remote sources.
 """
 
-from urllib.parse import urlparse
-from ...remote import s3
+from ...remote import parse_remote_path
 from ...util import warn
 
 
-SUPPORTED_SCHEMES = {
-    "s3": s3,
-}
-
-
 def register_parser(subparser):
     parser = subparser.add_parser(
         "delete",
@@ -34,15 +28,7 @@ def register_parser(subparser):
 
 
 def run(opts):
-    url = urlparse(opts.remote_path)
-
-    if url.scheme not in SUPPORTED_SCHEMES:
-        warn("Error: Unsupported remote scheme %s://" % url.scheme)
-        warn("")
-        warn("Supported schemes are: %s" % ", ".join(SUPPORTED_SCHEMES))
-        return 1
-
-    remote = SUPPORTED_SCHEMES[url.scheme]
+    remote, url = parse_remote_path(opts.remote_path)
 
     deleted = remote.delete(url, recursively = opts.recursively)
     deleted_count = 0
