@@ -14,11 +14,11 @@ or
 """
 
 import re
-import netifaces as net
 from pathlib import Path
-from typing import Iterable
+from socket import getaddrinfo, AddressFamily, SocketKind, AF_INET, AF_INET6, IPPROTO_TCP
+from typing import Iterable, NamedTuple, Tuple, Union
 from .. import runner
-from ..argparse import add_extended_help_flags
+from ..argparse import add_extended_help_flags, SUPPRESS
 from ..runner import docker, native
 from ..util import colored, remove_suffix, warn
 from ..volume import store_volume
@@ -37,14 +37,22 @@ def register_parser(subparser):
 
     parser.add_argument(
         "--allow-remote-access",
-        help   = "Allow other computers on the network to access the website",
-        action = "store_true")
+        help   = "Allow other computers on the network to access the website (alias for --host=0.0.0.0)",
+        dest   = "host",
+        action = "store_const",
+        const  = "0.0.0.0",
+        default = SUPPRESS)
+
+    parser.add_argument(
+        "--host",
+        help    = "Listen on the given hostname or IP address instead of the default %(default)s",
+        metavar = "<ip/hostname>",
+        default = "127.0.0.1")
 
     parser.add_argument(
         "--port",
         help    = "Listen on the given port instead of the default port %(default)s",
         metavar = "<number>",
-        type    = int,
         default = 4000)
 
     # Positional parameters
@@ -85,8 +93,7 @@ def run(opts):
     # The environment variables HOST and PORT are respected by auspice's
     # cli/view.js.  HOST requires a new enough version of Auspice; 1.35.7 and
     # earlier always listen on 0.0.0.0 or ::.
-    host = "0.0.0.0" if opts.allow_remote_access else "127.0.0.1"
-    port = opts.port
+    host, port = resolve(opts.host, opts.port)
 
     env = {
         'HOST': host,
@@ -114,21 +121,29 @@ def run(opts):
         "--env=HOST=0.0.0.0",
 
         # Publish the port
-        "--publish=%s:%d:%d" % (host, port, port),
+        "--publish=[%s]:%d:%d" % (host, port, port),
     ]
 
-    # Find the best remote address if we're allowing remote access.  While we
-    # listen on all interfaces (0.0.0.0), only the local host can connect to
-    # that successfully.  Remote hosts need a real IP on the network, which we
-    # do our best to discover.  If something goes wrong, ignore it and leave
-    # the host IP as-is (0.0.0.0); it'll at least work for local access.
-    if opts.allow_remote_access:
-        try:
-            remote_address = best_remote_address()
-        except:
-            pass
-        else:
-            host = remote_address
+    # XXX TODO: Find the best remote address if we're allowing remote access.
+    # While we listen on all interfaces (0.0.0.0), only the local host can
+    # connect to that successfully.  Remote hosts need a real IP on the
+    # network, which we do our best to discover.  If something goes wrong,
+    # ignore it and leave the host IP as-is (0.0.0.0); it'll at least work for
+    # local access.
+    #
+    # We used to use (in versions <= 3.0.4) the netifaces package to determine
+    # this, but netifaces became unmaintained and thus stopped having wheels
+    # built for newer Python versions.  This caused installation issues on a
+    # myriad of platforms since without wheels a full C toolchain is needed to
+    # install it.  For more context, see discussion starting with this comment:
+    #
+    #   <https://github.com/nextstrain/cli/issues/31#issuecomment-966609539>
+    #
+    # This comment exists as a reminder that spitting out http://0.0.0.0:4000
+    # is not very helpful and we should do better in the future if we
+    # reasonably can (e.g. use mDNS/Zeroconf to make nextstrain.your-computer.local
+    # Just Work, or even check if netifaces gets revived).
+    #   -trs, 17 Dec 2021
 
     # Show a helpful message about where to connect
     print_url(host, port, datasets)
@@ -169,6 +184,9 @@ def print_url(host, port, datasets):
     Prints a list of available dataset URLs, if any.  Otherwise, prints a
     generic URL.
     """
+    # Surround IPv6 addresses with square brackets for the URL.
+    if ":" in host:
+        host = f"[{host}]"
 
     def url(path = None):
         return colored(
@@ -196,28 +214,29 @@ def print_url(host, port, datasets):
     print()
 
 
-def best_remote_address():
+def resolve(host, port) -> Tuple[str, int]:
     """
-    Returns the "best" non-localback IP address for the local host, if
-    possible.  The "best" IP address is that bound to either the default
-    gateway interface, if any, else the arbitrary first interface found.
+    Resolves *host* to an address and *port* to a number, if either is a name.
 
-    IPv4 is preferred, but IPv6 will be used if no IPv4 interfaces/addresses
-    are available.
+    Returns a tuple of (ip, port) if possible; otherwise returns (host, port)
+    as given (which may work, but will probably fail).
+
+    IPv4 addresses are preferred, but IPv6 addresses be returned if no IPv4
+    addresses are available.
     """
-    default_gateway   = net.gateways().get("default", {})
-    default_interface = default_gateway.get(net.AF_INET,  (None, None))[1] \
-                     or default_gateway.get(net.AF_INET6, (None, None))[1] \
-                     or net.interfaces()[0]
+    addrs = [AddressInfo(*a) for a in getaddrinfo(host, port, proto = IPPROTO_TCP)]
 
-    interface_addresses = net.ifaddresses(default_interface).get(net.AF_INET)  \
-                       or net.ifaddresses(default_interface).get(net.AF_INET6) \
-                       or []
+    ip4 = [a for a in addrs if a.family is AF_INET]
+    ip6 = [a for a in addrs if a.family is AF_INET6]
 
-    addresses = [
-        address["addr"]
-            for address in interface_addresses
-             if address.get("addr")
-    ]
+    return ip4[0].sockaddr[0:2] if ip4 \
+      else ip6[0].sockaddr[0:2] if ip6 \
+      else (host, int(port))
 
-    return addresses[0] if addresses else None
+
+class AddressInfo(NamedTuple):
+    family: AddressFamily
+    type: SocketKind
+    proto: int
+    canonname: str
+    sockaddr: Union[Tuple[str, int], Tuple[str, int, int, int]] # (ip, addr, ...)
